==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OsobaRodzina.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypOsobyWRodzinie;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class OsobaRodzina extends GenericDPSObject {
    /**
     * OSOBA_RODZINA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * OSOBA_RODZINA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * OSOBA_RODZINA.RODZINA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rodzinaId;

    /**
     * OSOBA_RODZINA.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * OSOBA_RODZINA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String kodStopniaPokrewienstwa;

    /**
     * OSOBA_RODZINA.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypOsobyWRodzinie typ;

    /**
     * OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean zobowiazanyAlimentacja;

    /**
     * OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean zwolnionyAlimentacja;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_RODZINA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OSOBA_RODZINA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OSOBA_RODZINA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_RODZINA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_RODZINA.RODZINA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRodzinaId() {
        return rodzinaId;
    }

    /**
     * OSOBA_RODZINA.RODZINA_ID
     *
     * @param rodzinaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzinaId(Long rodzinaId) {
        this.rodzinaId = rodzinaId;
    }

    /**
     * @return OSOBA_RODZINA.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * OSOBA_RODZINA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return OSOBA_RODZINA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * OSOBA_RODZINA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getKodStopniaPokrewienstwa() {
        return kodStopniaPokrewienstwa;
    }

    /**
     * OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     *
     * @param kodStopniaPokrewienstwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodStopniaPokrewienstwa(String kodStopniaPokrewienstwa) {
        this.kodStopniaPokrewienstwa = kodStopniaPokrewienstwa == null ? null : kodStopniaPokrewienstwa.trim();
    }

    /**
     * @return OSOBA_RODZINA.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypOsobyWRodzinie getTyp() {
        return typ;
    }

    /**
     * OSOBA_RODZINA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypOsobyWRodzinie typ) {
        this.typ = typ;
    }

    /**
     * @return OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getZobowiazanyAlimentacja() {
        return zobowiazanyAlimentacja;
    }

    /**
     * OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     *
     * @param zobowiazanyAlimentacja
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZobowiazanyAlimentacja(Boolean zobowiazanyAlimentacja) {
        this.zobowiazanyAlimentacja = zobowiazanyAlimentacja;
    }

    /**
     * @return OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getZwolnionyAlimentacja() {
        return zwolnionyAlimentacja;
    }

    /**
     * OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     *
     * @param zwolnionyAlimentacja
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZwolnionyAlimentacja(Boolean zwolnionyAlimentacja) {
        this.zwolnionyAlimentacja = zwolnionyAlimentacja;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaRodzina other = (OsobaRodzina) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getRodzinaId() == null ? other.getRodzinaId() == null : this.getRodzinaId().equals(other.getRodzinaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKodStopniaPokrewienstwa() == null ? other.getKodStopniaPokrewienstwa() == null : this.getKodStopniaPokrewienstwa().equals(other.getKodStopniaPokrewienstwa()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getZobowiazanyAlimentacja() == null ? other.getZobowiazanyAlimentacja() == null : this.getZobowiazanyAlimentacja().equals(other.getZobowiazanyAlimentacja()))
            && (this.getZwolnionyAlimentacja() == null ? other.getZwolnionyAlimentacja() == null : this.getZwolnionyAlimentacja().equals(other.getZwolnionyAlimentacja()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getRodzinaId() == null) ? 0 : getRodzinaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKodStopniaPokrewienstwa() == null) ? 0 : getKodStopniaPokrewienstwa().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getZobowiazanyAlimentacja() == null) ? 0 : getZobowiazanyAlimentacja().hashCode());
        result = prime * result + ((getZwolnionyAlimentacja() == null) ? 0 : getZwolnionyAlimentacja().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", rodzinaId=").append(rodzinaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kodStopniaPokrewienstwa=").append(kodStopniaPokrewienstwa);
        sb.append(", typ=").append(typ);
        sb.append(", zobowiazanyAlimentacja=").append(zobowiazanyAlimentacja);
        sb.append(", zwolnionyAlimentacja=").append(zwolnionyAlimentacja);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OsobaRodzina.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypOsobyWRodzinie;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class OsobaRodzina extends GenericDPSObject {
    /**
     * OSOBA_RODZINA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * OSOBA_RODZINA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * OSOBA_RODZINA.RODZINA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rodzinaId;

    /**
     * OSOBA_RODZINA.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * OSOBA_RODZINA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String kodStopniaPokrewienstwa;

    /**
     * OSOBA_RODZINA.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypOsobyWRodzinie typ;

    /**
     * OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean zobowiazanyAlimentacja;

    /**
     * OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean zwolnionyAlimentacja;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return OSOBA_RODZINA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * OSOBA_RODZINA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return OSOBA_RODZINA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * OSOBA_RODZINA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return OSOBA_RODZINA.RODZINA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRodzinaId() {
        return rodzinaId;
    }

    /**
     * OSOBA_RODZINA.RODZINA_ID
     *
     * @param rodzinaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzinaId(Long rodzinaId) {
        this.rodzinaId = rodzinaId;
    }

    /**
     * @return OSOBA_RODZINA.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * OSOBA_RODZINA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return OSOBA_RODZINA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * OSOBA_RODZINA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getKodStopniaPokrewienstwa() {
        return kodStopniaPokrewienstwa;
    }

    /**
     * OSOBA_RODZINA.KOD_STOPNIA_POKREWIENSTWA
     *
     * @param kodStopniaPokrewienstwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodStopniaPokrewienstwa(String kodStopniaPokrewienstwa) {
        this.kodStopniaPokrewienstwa = kodStopniaPokrewienstwa == null ? null : kodStopniaPokrewienstwa.trim();
    }

    /**
     * @return OSOBA_RODZINA.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypOsobyWRodzinie getTyp() {
        return typ;
    }

    /**
     * OSOBA_RODZINA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypOsobyWRodzinie typ) {
        this.typ = typ;
    }

    /**
     * @return OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getZobowiazanyAlimentacja() {
        return zobowiazanyAlimentacja;
    }

    /**
     * OSOBA_RODZINA.ZOBOWIAZANY_ALIMENTACJA
     *
     * @param zobowiazanyAlimentacja
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZobowiazanyAlimentacja(Boolean zobowiazanyAlimentacja) {
        this.zobowiazanyAlimentacja = zobowiazanyAlimentacja;
    }

    /**
     * @return OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getZwolnionyAlimentacja() {
        return zwolnionyAlimentacja;
    }

    /**
     * OSOBA_RODZINA.ZWOLNIONY_ALIMENTACJA
     *
     * @param zwolnionyAlimentacja
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZwolnionyAlimentacja(Boolean zwolnionyAlimentacja) {
        this.zwolnionyAlimentacja = zwolnionyAlimentacja;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OsobaRodzina other = (OsobaRodzina) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getRodzinaId() == null ? other.getRodzinaId() == null : this.getRodzinaId().equals(other.getRodzinaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getKodStopniaPokrewienstwa() == null ? other.getKodStopniaPokrewienstwa() == null : this.getKodStopniaPokrewienstwa().equals(other.getKodStopniaPokrewienstwa()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getZobowiazanyAlimentacja() == null ? other.getZobowiazanyAlimentacja() == null : this.getZobowiazanyAlimentacja().equals(other.getZobowiazanyAlimentacja()))
            && (this.getZwolnionyAlimentacja() == null ? other.getZwolnionyAlimentacja() == null : this.getZwolnionyAlimentacja().equals(other.getZwolnionyAlimentacja()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getRodzinaId() == null) ? 0 : getRodzinaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getKodStopniaPokrewienstwa() == null) ? 0 : getKodStopniaPokrewienstwa().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getZobowiazanyAlimentacja() == null) ? 0 : getZobowiazanyAlimentacja().hashCode());
        result = prime * result + ((getZwolnionyAlimentacja() == null) ? 0 : getZwolnionyAlimentacja().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", rodzinaId=").append(rodzinaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", kodStopniaPokrewienstwa=").append(kodStopniaPokrewienstwa);
        sb.append(", typ=").append(typ);
        sb.append(", zobowiazanyAlimentacja=").append(zobowiazanyAlimentacja);
        sb.append(", zwolnionyAlimentacja=").append(zwolnionyAlimentacja);
        sb.append("]");
        return sb.toString();
    }
}
